var searchData=
[
  ['data_0',['User Data',['../dir_9e7e5f4b17eb9633bc62b35aca1d4fce.html#autotoc_md10',1,'']]],
  ['data_20transfer_1',['Data Transfer',['../_hardware-_buffers.html#Data-Transfer',1,'']]],
  ['debugging_20shaders_2',['Tips for debugging shaders',['../rtss.html#debugging',1,'']]],
  ['debugging_20shadows_3',['Debugging Shadows',['../_shadow_mapping_ogre.html#autotoc_md61',1,'']]],
  ['deciding_20on_20the_20gbuffer_20format_4',['Deciding on the GBuffer format',['../deferred.html#autotoc_md275',1,'']]],
  ['declaration_5',['Resource-Declaration',['../_resource-_management.html#Resource-Declaration',1,'']]],
  ['declarations_6',['Vertex Declarations',['../_hardware-_buffers.html#Vertex-Declarations',1,'']]],
  ['declaring_20shared_20parameters_7',['Declaring Shared Parameters',['../_high-level-_programs.html#Declaring-Shared-Parameters',1,'']]],
  ['declaring_20the_20use_20of_20vertex_20texture_20fetching_8',['Declaring the use of vertex texture fetching',['../_high-level-_programs.html#autotoc_md200',1,'']]],
  ['decorwidget_9',['DecorWidget',['../trays.html#autotoc_md325',1,'']]],
  ['default_20program_20parameters_10',['Default Program Parameters',['../_high-level-_programs.html#Default-Program-Parameters',1,'']]],
  ['default_20renderstate_11',['Customizing the default RenderState',['../rtss.html#rtss_custom_api',1,'']]],
  ['deferred_20shading_12',['Deferred Shading',['../deferred.html',1,'Deferred Shading'],['../deferred.html#what',1,'What is Deferred Shading?']]],
  ['deferred_20shading_20advantages_13',['Deferred Shading Advantages',['../deferred.html#autotoc_md273',1,'']]],
  ['deferred_20shading_20disadvantages_14',['Deferred Shading Disadvantages',['../deferred.html#autotoc_md274',1,'']]],
  ['defines_15',['Built-in defines',['../_cross-platform-_shaders.html#autotoc_md204',1,'']]],
  ['defining_20a_20terrain_20chunk_16',['Defining a terrain chunk',['../tut__terrain_sky_fog.html#bt3TerrainChunk',1,'']]],
  ['definition_20scripts_17',['Font Definition Scripts',['../_font-_definition-_scripts.html',1,'Scripts']]],
  ['definitions_18',['Chunk Definitions',['../group___paging.html#autotoc_md1',1,'']]],
  ['definitions_19',['Preprocessor definitions',['../_high-level-_programs.html#Preprocessor-definitions',1,'']]],
  ['deflectorplane_20affector_20',['DeflectorPlane Affector',['../_particle-_scripts.html#DeflectorPlane-Affector',1,'']]],
  ['defragmenting_20batches_21',['Defragmenting batches',['../_what_is_instancing.html#InstancingDefragmentingBatches',1,'']]],
  ['defragmenting_20on_20the_20fly_22',['Cure: Defragmenting on the fly',['../_what_is_instancing.html#InstancingDefragmentingBatchesOnTheFly',1,'']]],
  ['dependencies_23',['dependencies',['../building-ogre.html#autotoc_md265',1,'Deprecated dependencies'],['../building-ogre.html#autotoc_md261',1,'Getting dependencies'],['../building-ogre.html#autotoc_md264',1,'Optional dependencies'],['../building-ogre.html#autotoc_md263',1,'Recommended dependencies']]],
  ['deprecated_20dependencies_24',['Deprecated dependencies',['../building-ogre.html#autotoc_md265',1,'']]],
  ['deprecated_20list_25',['Deprecated List',['../deprecated.html',1,'']]],
  ['depth_26',['Depth',['../reversed-depth.html',1,'Reversed Depth'],['../rtss.html#rtss_indepth',1,'The RTSS in Depth']]],
  ['depth_20biasing_27',['Depth Biasing',['../_shadow_mapping_ogre.html#DepthBias',1,'']]],
  ['depth_20buffer_28',['Prepare ambient colour and rebuild original depth buffer',['../deferred.html#autotoc_md284',1,'']]],
  ['depth_20buffer_20sharing_29',['Shadow texture Depth Buffer sharing',['../_shadows.html#autotoc_md52',1,'']]],
  ['depth_20precision_20aliasing_30',['Sampling Aliasing versus Depth Precision Aliasing',['../_shadow_mapping_ogre.html#sm_aliasing',1,'']]],
  ['depth_5fbias_31',['depth_bias',['../_material-_scripts.html#autotoc_md133',1,'']]],
  ['depth_5fcheck_32',['depth_check',['../_material-_scripts.html#autotoc_md130',1,'']]],
  ['depth_5ffail_5fop_33',['depth_fail_op',['../_compositor-_scripts.html#autotoc_md93',1,'']]],
  ['depth_5ffunc_34',['depth_func',['../_material-_scripts.html#autotoc_md132',1,'']]],
  ['depth_5fvalue_35',['depth_value',['../_compositor-_scripts.html#autotoc_md86',1,'']]],
  ['depth_5fwrite_36',['depth_write',['../_material-_scripts.html#autotoc_md131',1,'']]],
  ['descriptions_37',['Descriptions',['../_material-_scripts.html#autotoc_md121',1,'Attribute Descriptions'],['../_material-_scripts.html#autotoc_md157',1,'Attribute Descriptions']]],
  ['diagram_20of_20process_38',['Simplified Diagram of Process',['../_external-_texture-_sources.html#autotoc_md297',1,'']]],
  ['dialog_39',['Dialog',['../trays.html#autotoc_md331',1,'Information Dialog'],['../trays.html#autotoc_md332',1,'Question Dialog']]],
  ['diffuse_40',['diffuse',['../_material-_scripts.html#autotoc_md123',1,'']]],
  ['direct_20memory_20locking_41',['Direct memory locking',['../_hardware-_buffers.html#Direct-memory-locking',1,'']]],
  ['direction_42',['direction',['../_particle-_scripts.html#autotoc_md228',1,'']]],
  ['direction_5fposition_5freference_43',['direction_position_reference',['../_particle-_scripts.html#autotoc_md229',1,'']]],
  ['directional_20lights_44',['Directional Lights',['../_shadows.html#autotoc_md42',1,'Directional Lights'],['../_shadows.html#autotoc_md49',1,'Shadow texture offset (Directional Lights)']]],
  ['directionrandomiser_20affector_45',['DirectionRandomiser Affector',['../_particle-_scripts.html#DirectionRandomiser-Affector',1,'']]],
  ['directive_46',['Script Import Directive',['../_scripts.html#Script-Import-Directive',1,'']]],
  ['directly_47',['Using vertex and index buffers directly',['../manual-mesh-creation.html#autotoc_md300',1,'']]],
  ['directx_20hlsl_48',['DirectX HLSL',['../_high-level-_programs.html#HLSL',1,'']]],
  ['directx9_20binding_20limitations_49',['DirectX9 binding limitations',['../_high-level-_programs.html#autotoc_md201',1,'']]],
  ['disabling_20individual_20profiles_50',['Disabling Individual Profiles',['../profiler.html#autotoc_md303',1,'']]],
  ['disabling_20the_20profiler_51',['Disabling the Profiler',['../profiler.html#autotoc_md302',1,'']]],
  ['disadvantages_52',['Deferred Shading Disadvantages',['../deferred.html#autotoc_md274',1,'']]],
  ['display_53',['Display',['../profiler.html#autotoc_md306',1,'Changing the Frequency of Updating the Display'],['../profiler.html#profRead',1,'Reading the Display']]],
  ['distance_54',['distance',['../_shadows.html#autotoc_md36',1,'Extrusion distance'],['../_shadows.html#autotoc_md48',1,'Shadow far distance']]],
  ['dotscene_55',['DotScene',['../dir_9e7e5f4b17eb9633bc62b35aca1d4fce.html#autotoc_md11',1,'How to use DotScene'],['../dir_9e7e5f4b17eb9633bc62b35aca1d4fce.html#autotoc_md9',1,'What is DotScene?']]],
  ['duration_56',['duration',['../_particle-_scripts.html#autotoc_md236',1,'']]],
  ['duration_5fmax_57',['duration_min &amp;amp; duration_max',['../_particle-_scripts.html#autotoc_md237',1,'']]],
  ['duration_5fmin_20duration_5fmax_58',['duration_min &amp;amp; duration_max',['../_particle-_scripts.html#autotoc_md237',1,'']]]
];
